package com.zanxiang.game.module.manage.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zanxiang.game.module.manage.enums.KfRoomMsgOwnerEnum;
import com.zanxiang.game.module.manage.enums.KfRoomMsgTypeEnum;
import com.zanxiang.game.module.manage.pojo.dto.KfAppletMsgDTO;
import com.zanxiang.game.module.manage.pojo.dto.KfMsgDTO;
import com.zanxiang.game.module.manage.service.IKfRoomMsgService;
import com.zanxiang.game.module.manage.websocket.KfMsgWebsocketHandler;
import com.zanxiang.game.module.mybatis.entity.KfRoomMsg;
import com.zanxiang.game.module.mybatis.mapper.KfRoomMsgMapper;
import com.zanxiang.module.util.JsonUtil;
import com.zanxiang.module.util.bean.BeanUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/**
 * @author : lingfeng
 * @time : 2024-02-23
 * @description : 客服聊天房间消息
 */
@Slf4j
@Service
public class KfRoomMsgServiceImpl extends ServiceImpl<KfRoomMsgMapper, KfRoomMsg> implements IKfRoomMsgService {


    @Autowired
    private KfMsgWebsocketHandler kfMsgWebsocketHandler;

    @Override
    public void appletMsg(String postData) {
        log.error("接收到SDK转发的小程序消息, postData : {}", postData);
        KfAppletMsgDTO kfAppletMsgDTO = JsonUtil.toObj(postData, KfAppletMsgDTO.class);
        //用户进入会话事件
        if (Objects.equals(kfAppletMsgDTO.getMsgType(), KfAppletMsgDTO.MSG_TYPE_EVENT)
                && Objects.equals(kfAppletMsgDTO.getEvent(), KfAppletMsgDTO.EVENT_USER_ENTER_TEMP_SESSION)) {
            //创建用户信息
            return;
        }
        //非玩家消息, 不做处理
        if (kfAppletMsgDTO.getMsgId() == null) {
            return;
        }
        //消息存储
        KfRoomMsg kfRoomMsg = KfRoomMsg.builder()
                .msgId(String.valueOf(kfAppletMsgDTO.getMsgId()))
                .msgType(kfAppletMsgDTO.getMsgType())
                .readStatus(Boolean.FALSE)
                .msgOwner(KfRoomMsgOwnerEnum.KF_MSG_OWNER_USER.getValue())
                .content(this.getMsgContent(kfAppletMsgDTO))
                .source(postData)
                .createTime(LocalDateTime.now())
                .build();
        super.save(kfRoomMsg);
        // 消息转发到redis频道
        kfMsgWebsocketHandler.pushMessage(JsonUtil.toString(BeanUtil.copy(kfRoomMsg, KfMsgDTO.class)));
    }

    private String getMsgContent(KfAppletMsgDTO kfAppletMsgDTO) {
        Map<String, String> contentMap = new HashMap<>(2);
        if (Objects.equals(KfRoomMsgTypeEnum.KF_MSG_TYPE_TEXT.getValue(), kfAppletMsgDTO.getMsgType())) {
            contentMap.put("text", kfAppletMsgDTO.getContent());
        }
        if (Objects.equals(KfRoomMsgTypeEnum.KF_MSG_TYPE_IMAGE.getValue(), kfAppletMsgDTO.getMsgType())) {
            contentMap.put("picUrl", kfAppletMsgDTO.getPicUrl());
            contentMap.put("mediaId", kfAppletMsgDTO.getMediaId());
        }
        return JsonUtil.toString(contentMap);
    }

}
