package com.zanxiang.game.module.manage.websocket;

import com.zanxiang.game.module.manage.constant.RedisKeyConstant;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;
import org.springframework.web.socket.CloseStatus;
import org.springframework.web.socket.WebSocketHandler;
import org.springframework.web.socket.WebSocketMessage;
import org.springframework.web.socket.WebSocketSession;

/**
 * @author : lingfeng
 * @time : 2024-02-23
 * @description : 客服消息Websocket处理器
 */
@Slf4j
@Lazy(value = false)
@Component
public class KfMsgWebsocketHandler implements WebSocketHandler {

    @Autowired
    private RedisTemplate<String, String> redisTemplate;

    @Autowired
    private KfMsgWebSocketSessionRegistry kfMsgWebSocketSessionRegistry;

    /**
     * websocket连接建立成功
     */
    @Override
    public void afterConnectionEstablished(WebSocketSession session) throws Exception {
        log.error("前端长连接建立成功");
    }

    /**
     * 收到消息
     */
    @Override
    public void handleMessage(WebSocketSession session, WebSocketMessage<?> message) throws Exception {
        String msgStr = message.getPayload().toString();
        log.error("收到前端消息 msgStr : {}", msgStr);
        kfMsgWebSocketSessionRegistry.addSession(msgStr, session);
        this.pushMessage(msgStr + "_" + "你好!武哥");
    }

    /**
     * 消息传输发生错误
     */
    @Override
    public void handleTransportError(WebSocketSession session, Throwable exception) throws Exception {
        log.error("发生错误");
    }

    /**
     * 连接被关闭
     */
    @Override
    public void afterConnectionClosed(WebSocketSession session, CloseStatus closeStatus) throws Exception {
        log.error("连接被关闭");
    }

    @Override
    public boolean supportsPartialMessages() {
        return false;
    }

    /**
     * 消息发送到redis广播
     */
    public void pushMessage(String message) {
        redisTemplate.convertAndSend(RedisKeyConstant.KF_MSG_REDIS_LISTEN_TOPIC, message);
    }
}
